package com.ruoyi.system.mapper.fgw;

import java.util.List;
import com.ruoyi.system.domain.fgw.FgwLdps;

/**
 * 发改委_领导批示Mapper接口
 * 
 * @author ruoyi
 * @date 2023-03-24
 */
public interface FgwLdpsMapper 
{
    /**
     * 查询发改委_领导批示
     * 
     * @param id 发改委_领导批示主键
     * @return 发改委_领导批示
     */
    public FgwLdps selectFgwLdpsById(Long id);

    /**
     * 查询发改委_领导批示列表
     * 
     * @param fgwLdps 发改委_领导批示
     * @return 发改委_领导批示集合
     */
    public List<FgwLdps> selectFgwLdpsList(FgwLdps fgwLdps);

    /**
     * 新增发改委_领导批示
     * 
     * @param fgwLdps 发改委_领导批示
     * @return 结果
     */
    public int insertFgwLdps(FgwLdps fgwLdps);

    /**
     * 修改发改委_领导批示
     * 
     * @param fgwLdps 发改委_领导批示
     * @return 结果
     */
    public int updateFgwLdps(FgwLdps fgwLdps);

    /**
     * 删除发改委_领导批示
     * 
     * @param id 发改委_领导批示主键
     * @return 结果
     */
    public int deleteFgwLdpsById(Long id);

    /**
     * 批量删除发改委_领导批示
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFgwLdpsByIds(Long[] ids);

    FgwLdps getInfoZc(FgwLdps fgwLdps);

    List<FgwLdps> selectFgwLdpsNew(Long xmId);
}
